{***************************************************************
 *
 * Unit Name: AboutWindows
 * Purpose  : componente TAboutWindows
 * Author   : Francesco Tinti
 * History  : 03.12.1999
 *
 ****************************************************************}

unit AboutWindows;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Registry;

type
  TOperatingSystem = ( osWin95, osWin98, osWinNT, osWin2000, osWinMillennium );
  TAboutWindows = class(TComponent)
   private
    FCSDVersion: string;
    FCurrentBuild: string;
    FCurrentBuildNumber: string;
    FCurrentVersion: string;
    FOperatingSystem: TOperatingSystem;
    FPlusVersionNumber: string;
    FProductID: string;
    FProductKey: string;
    FProductName: string;
    FRegisteredOrganization: string;
    FRegisteredOwner: string;
    FVersion: string;
    FVersionNumber: string;

    FCreate: TNotifyEvent;
    FDestroy: TNotifyEvent;
    procedure CheckOperatingSystem;
  protected
    // soltanto per NT: Versione del Service Pack
    function GetCSDVersion: string;
    procedure SetCSDVersion(NewCSDVersion: string);

    // soltanto per NT: Versione Build Corrente
    function GetCurrentBuild: string;
    procedure SetCurrentBuild(NewCurrentBuild: string);

    // soltanto per NT: Numero Build Corrente
    function GetCurrentBuildNumber: string;
    procedure SetCurrentBuildNumber(NewCurrentBuildNumber: string);

    // soltanto per NT: Versione del prodotto (4.0)
    function GetCurrentVersion: string;
    procedure SetCurrentVersion(NewCurrentVersion: string);

    // By ZeroTime
    function GetOperatingSystem: TOperatingSystem;
    procedure SetOperatingSystem(NewOperatingSystem: TOperatingSystem);

    function GetPlusVersionNumber: string;
    procedure SetPlusVersionNumber(NewPlusVersionNumber: string);

    function GetProductID: string;
    procedure SetProductID(NewProductID: string);

    // soltanto per Win 98
    function GetProductKey: string;
    procedure SetProductKey(NewProductKey: string);

    // Win98? Wiindows Millennium
    function GetProductName: string;
    procedure SetProductName(NewProductName: string);

    function GetRegisteredOrganization: string;
    procedure SetRegisteredOrganization(NewRegisteredOrganization: string);

    function GetRegisteredOwner: string; overload;
    procedure SetRegisteredOwner(NewRegisteredOwner: string);

    // soltanto per Win 95/98
    function GetVersion: string;
    procedure SetVersion(NewVersion: string);

    // soltanto per Win 95/98
    function GetVersionNumber: string;
    procedure SetVersionNumber(NewVersionNumber: string);
  public
   constructor Create(AOwner: TComponent); override;
   destructor Destroy; override;

  published
   property CSDVersion: string Read GetCSDVersion Write SetCSDVersion;
   property CurrentBuild: string Read GetCurrentBuild Write SetCurrentBuild;
   property CurrentBuildNumber: string Read GetCurrentBuildNumber Write SetCurrentBuildNumber;
   property CurrentVersion: string Read GetCurrentVersion Write SetCurrentVersion;
   property OperatingSystem: TOperatingSystem Read GetOperatingSystem Write SetOperatingSystem;
   property PlusVersionNumber: string Read GetPlusVersionNumber Write SetPlusVersionNumber;
   property ProductID: string Read GetProductID Write SetProductID;
   property ProductKey: string Read GetProductKey Write SetProductKey;
   property ProductName: string Read GetProductName Write SetProductName;
   property RegisteredOrganization: string Read GetRegisteredOrganization Write SetRegisteredOrganization;
   property RegisteredOwner: string Read GetRegisteredOwner Write SetRegisteredOwner;
   property Version: string Read GetVersion Write SetVersion;
   property VersionNumber: string Read GetVersionNumber Write SetVersionNumber;

   property OnCreate: TNotifyEvent Read FCreate Write FCreate;
   property OnDestroy: TNotifyEvent Read FDestroy Write FDestroy;
  end;

implementation

resourcestring
 strWin95              = 'Microsoft Windows 95';
 strWin98              = 'Microsoft Windows 98';
 strWinNT              = 'Microsoft Windows NT';
 strWin2000            = 'Microsoft Windows 2000';
 strWinMillennium      = 'Microsoft Windows Millennium';

//******************* TAboutWindows.Create *************************
constructor TAboutWindows.Create(AOwner: TComponent);
var FReg: TRegistry;
begin
 inherited Create(AOwner);

 FReg := TRegistry.Create;
 FReg.RootKey := HKEY_LOCAL_MACHINE;

 // per windows 95/98
// SetOperatingSystem( toWin98 );
 FReg.OpenKey('\Software\Microsoft\Windows\CurrentVersion', False);
 SetProductKey(FReg.ReadString('ProductKey'));
  if FProductKey = '' then begin // per Windows NT
   FReg.CloseKey;
   FReg.OpenKey('\Software\Microsoft\Windows NT\CurrentVersion', False);
  end;

 SetCSDVersion(FReg.ReadString('CSDVersion'));
 SetCurrentBuild(FReg.ReadString('CurrentBuild'));
 SetCurrentBuildNumber(FReg.ReadString('CurrentBuildNumber'));
 SetCurrentVersion(FReg.ReadString('CurrentVersion'));
 SetPlusVersionNumber(FReg.ReadString('Plus! VersionNumber'));
 SetProductID(FReg.ReadString('ProductID'));

 setProductName(FReg.ReadString('ProductName'));
 CheckOperatingSystem;

 SetRegisteredOrganization(FReg.ReadString('RegisteredOrganization'));
 SetRegisteredOwner(FReg.ReadString('RegisteredOwner'));
 SetVersion(FReg.ReadString('Version'));
 SetVersionNumber(FReg.ReadString('VersionNumber'));
 FReg.Free;
end;

//******************* TAboutWindows.Destroy *************************
destructor TAboutWindows.Destroy;
begin
 inherited Destroy;
end;

procedure TAboutWindows.CheckOperatingSystem;
var
 VOS: TOperatingSystem;
begin
      if (FProductName = strWin95) then VOS := osWin95
 else if (FProductName = strWin98) then VOS := osWin98
 else if (FProductName = strWinNT) then  VOS := osWinNT
 else if (FProductName = strWin2000) then VOS := osWin2000
 else if (FProductName = strWinMillennium) then VOS := osWinMillennium;

 SetOperatingSystem(VOS);
end;

//******************* GetCSDVersion *************************
function TAboutWindows.GetCSDVersion: string;
begin
 Result := FCSDVersion;
end;

//******************* SetCSDVersion *************************
procedure TAboutWindows.SetCSDVersion(NewCSDVersion: string);
begin
 FCSDVersion := NewCSDVersion;
end;

// soltanto per NT: Versione Build Corrente
function TAboutWindows.GetCurrentBuild: string;
begin
 Result := FCurrentBuild;
end;

//******************* TAboutWindows.SetCurrentBuild *************************
procedure TAboutWindows.SetCurrentBuild(NewCurrentBuild: string);
begin
 FCurrentBuild := NewCurrentBuild;
end;

// soltanto per NT: Numero Build Corrente
function TAboutWindows.GetCurrentBuildNumber: string;
begin
 Result := FCurrentBuildNumber;
end;

//******************* TAboutWindows.GetCurrentVersion *************************
function TAboutWindows.GetCurrentVersion: string;
begin
 Result := FCurrentVersion;
end;

//******************* TAboutWindows.SetCurrentVersion *************************
procedure TAboutWindows.SetCurrentVersion(NewCurrentVersion: string);
begin
 FCurrentVersion := NewCurrentVersion;
end;

//******************* TAboutWindows.SetCurrentBuildNumber *************************
procedure TAboutWindows.SetCurrentBuildNumber(NewCurrentBuildNumber: string);
begin
 FCurrentBuildNumber := NewCurrentBuildNumber;
end;

//******************* TAboutWindows.GetOperatingSystem *************************
function TAboutWindows.GetOperatingSystem: TOperatingSystem;
begin
 Result := FOperatingSystem;
end;

//******************* TAboutWindows.SetOperatingSystem *************************
procedure TAboutWindows.SetOperatingSystem(NewOperatingSystem: TOperatingSystem);
begin
 FOperatingSystem := NewOperatingSystem;
end;

//******************* TAboutWindows.GetPlusVersionNumber *************************
function TAboutWindows.GetPlusVersionNumber: string;
begin
 Result := FPlusVersionNumber;
end;

procedure TAboutWindows.SetPlusVersionNumber(NewPlusVersionNumber: string);
begin
 FPlusVersionNumber := NewPlusVersionNumber;
end;


//******************* TAboutWindows.GetProductID *************************
function TAboutWindows.GetProductID: string;
begin
 Result := FProductID;
end;

//******************* TAboutWindows.SetProductID *************************
procedure TAboutWindows.SetProductID(NewProductID: string);
begin
 FProductID := NewProductID;
end;

//******************* TAboutWindows.GetProductKey *************************
function TAboutWindows.GetProductKey: string;
begin
 Result := FProductKey;
end;

//******************* TAboutWindows.SetProductKey *************************
procedure TAboutWindows.SetProductKey(NewProductKey: string);
begin
 FProductKey := NewProductKey;
end;

//******************* TAboutWindows.GetProductName *************************
function TAboutWindows.GetProductName: string;
begin
 Result := FProductName;
end;

//******************* TAboutWindows.SetProductName *************************
procedure TAboutWindows.SetProductName(NewProductName: string);
begin
 FProductName := NewProductName;
end;

//******************* TAboutWindows.GetOrganization *************************
function TAboutWindows.GetRegisteredOrganization: string;
begin
 Result := FRegisteredOrganization;
end;

//******************* TAboutWindows.SetOrganization *************************
procedure TAboutWindows.SetRegisteredOrganization(NewRegisteredOrganization: string);
begin
 FRegisteredOrganization := NewRegisteredOrganization;
end;

//******************* TAboutWindows.GetOwner *************************
function TAboutWindows.GetRegisteredOwner: string;
begin
 Result := FRegisteredOwner;
end;

//******************* TAboutWindows.SetOwner *************************
procedure TAboutWindows.SetRegisteredOwner(NewRegisteredOwner: string);
begin
 FRegisteredOwner := NewRegisteredOwner;
end;

//******************* TAboutWindows.GetVersion *************************
function TAboutWindows.GetVersion: string;
begin
 Result := FVersion;
end;

//******************* TAboutWindows.SetVersion *************************
procedure TAboutWindows.SetVersion(NewVersion: string);
begin
 FVersion := NewVersion;
end;

//******************* TAboutWindows.GetVersionNumber *************************
function TAboutWindows.GetVersionNumber: string;
begin
 Result := FVersionNumber;
end;

//******************* TAboutWindows.SetVersionNumber *************************
procedure TAboutWindows.SetVersionNumber(NewVersionNumber: string);
begin
 FVersionNumber := NewVersionNumber;
end;

end.








